@@ -67,8 +67,8 @@
 #include "fetch.h"
 #include "x509more.h"
 
-#ifdef HAVE_OCF_AND_OPENSSL
-#include "ocf_cryptodev.h"
+#ifdef HAVE_OCF
+#include "ocf_pk.h"
 #endif
 
 /* Maximum length of filename and passphrase buffer */
@@ -150,16 +150,13 @@ sign_hash(const struct RSA_private_key *k, const u_char *hash_val, size_t hash_l
     , u_char *sig_val, size_t sig_len)
 {
     chunk_t ch;
-#ifdef HAVE_OCF_AND_OPENSSL
+#if defined(HAVE_OCF) && 0
     mpz_t t1;
 #else
     mpz_t t1, t2;
 #endif
     size_t padlen;
     u_char *p = sig_val;
-#ifdef HAVE_OCF_AND_OPENSSL
-    BIGNUM r0;
-#endif
 
     DBG(DBG_CONTROL | DBG_CRYPT,
 	DBG_log("signing hash with RSA Key *%s", k->pub.keyid)
@@ -182,10 +179,8 @@ sign_hash(const struct RSA_private_key *k, const u_char *hash_val, size_t hash_l
      * There are two methods, depending on the form of the private key.
      * We use the one based on the Chinese Remainder Theorem.
      */
-#ifdef HAVE_OCF_AND_OPENSSL
-    BN_init(&r0);
-    cryptodev.rsa_mod_exp_crt(k, &t1, &r0);
-    bn2mp(&r0, (MP_INT *) &t1);
+#if defined(HAVE_OCF) && 0
+    cryptodev.rsa_mod_exp_crt(&t1, &t1, &r0);
 #else
     mpz_init(t2);
 
@@ -206,9 +201,9 @@ sign_hash(const struct RSA_private_key *k, const u_char *hash_val, size_t hash_l
     ch = mpz_to_n(t1, sig_len);
     memcpy(sig_val, ch.ptr, sig_len);
     pfree(ch.ptr);
-#ifndef HAVE_OCF_AND_OPENSSL
 
     mpz_clear(t1);
+#if !defined(HAVE_OCF) && 0
     mpz_clear(t2);
 #endif
 }
