@@ -86,8 +86,8 @@
 #include "tpm/tpm.h"
 #endif
 
-#ifdef HAVE_OCF_AND_OPENSSL
-#include "ocf_cryptodev.h"
+#ifdef HAVE_OCF
+#include "ocf_pk.h"
 #endif
 
 #ifndef IPSECDIR
@@ -791,7 +791,7 @@ main(int argc, char **argv)
     init_connections();
     init_crypto();
     init_crypto_helpers(nhelpers);
-#ifdef HAVE_OCF_AND_OPENSSL
+#ifdef HAVE_OCF
     load_cryptodev();
 #endif
     init_demux();
